@@ -1,7 +1,8 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Any, Optional
-import os
+
 import logging
+import os
+from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
     from .site import Site
@@ -24,7 +25,7 @@ class Archetype:
         """
         # By default, render the archetype with jinja2
         abspath = os.path.join(self.archetypes.root, self.relpath)
-        with open(abspath, "rt") as fd:
+        with open(abspath) as fd:
             template = self.site.theme.jinja2.from_string(fd.read())
         rendered = template.render(**kw)
         return {}, rendered
@@ -37,7 +38,7 @@ class Archetypes:
         # Root directory where archetypes are found
         self.root = root
 
-    def find(self, name: str) -> Optional[Archetype]:
+    def find(self, name: str) -> Archetype | None:
         """
         Read the archetypes directory and return the archetype that matches the given name.
 
