@@ -20,12 +20,24 @@ class DumpMeta(SiteCommand):
     NAME = "dump_meta"
 
     @classmethod
-    def add_subparser(cls, subparsers: "argparse._SubParsersAction[Any]") -> argparse.ArgumentParser:
+    def add_subparser(
+        cls, subparsers: argparse._SubParsersAction[Any]
+    ) -> argparse.ArgumentParser:
         parser = super().add_subparser(subparsers)
-        parser.add_argument("-f", "--format", action="store", default="yaml",
-                            help="format to use for output")
-        parser.add_argument("-p", "--pages", nargs="+", default=(),
-                            help="globs or regexps matching pages to show")
+        parser.add_argument(
+            "-f",
+            "--format",
+            action="store",
+            default="yaml",
+            help="format to use for output",
+        )
+        parser.add_argument(
+            "-p",
+            "--pages",
+            nargs="+",
+            default=(),
+            help="globs or regexps matching pages to show",
+        )
         return parser
 
     def run(self) -> None:
@@ -33,7 +45,7 @@ class DumpMeta(SiteCommand):
         filters = [compile_page_match(f) for f in self.args.pages]
         res = {}
         # show_repr = self.args.repr
-        for site_path, page in sorted(((p.site_path, p) for p in site.iter_pages())):
+        for site_path, page in sorted((p.site_path, p) for p in site.iter_pages()):
             if filters and not any(f.match(site_path) for f in filters):
                 continue
             res[site_path] = page.to_dict()
