@@ -2,7 +2,8 @@ from __future__ import annotations
 
 import logging
 import os
-from typing import Generator, NamedTuple
+from collections.abc import Generator
+from typing import NamedTuple
 
 log = logging.getLogger("contents")
 
@@ -13,6 +14,7 @@ class File(NamedTuple):
 
     If stat is not None, the file exists and these are its stats.
     """
+
     # Relative path to root
     relpath: str
     # Absolute path to the file
@@ -27,11 +29,12 @@ class File(NamedTuple):
             return self.relpath
 
     @classmethod
-    def from_dir_entry(cls, dir: "File", entry: os.DirEntry[str]) -> "File":
+    def from_dir_entry(cls, dir: File, entry: os.DirEntry[str]) -> File:
         return cls(
-                relpath=os.path.join(dir.relpath, entry.name),
-                abspath=os.path.join(dir.abspath, entry.name),
-                stat=entry.stat())
+            relpath=os.path.join(dir.relpath, entry.name),
+            abspath=os.path.join(dir.abspath, entry.name),
+            stat=entry.stat(),
+        )
 
     @classmethod
     def with_stat(cls, relpath: str, abspath: str) -> File:
@@ -39,14 +42,14 @@ class File(NamedTuple):
 
     @classmethod
     def scan(
-            cls,
-            abspath: str,
-            follow_symlinks: bool = False,
-            ignore_hidden: bool = False) -> Generator[File, None, None]:
+        cls, abspath: str, follow_symlinks: bool = False, ignore_hidden: bool = False
+    ) -> Generator[File, None, None]:
         """
         Scan tree_root, generating relative paths based on it
         """
-        for root, dnames, fnames, dirfd in os.fwalk(abspath, follow_symlinks=follow_symlinks):
+        for root, dnames, fnames, dirfd in os.fwalk(
+            abspath, follow_symlinks=follow_symlinks
+        ):
             if ignore_hidden:
                 # Ignore hidden directories
                 filtered = [d for d in dnames if not d.startswith(".")]
@@ -65,6 +68,5 @@ class File(NamedTuple):
                     continue
                 relpath = os.path.join(root, f)
                 yield cls(
-                        relpath=relpath,
-                        abspath=os.path.join(abspath, relpath),
-                        stat=st)
+                    relpath=relpath, abspath=os.path.join(abspath, relpath), stat=st
+                )
