@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import datetime
 import logging
-from typing import TYPE_CHECKING, Any, Optional, Type, TypeVar
+from typing import TYPE_CHECKING, Any, TypeVar
 
 from . import fields, file
 from .node import Node, SkipPage
@@ -22,21 +22,27 @@ class SourceNode(Node):
     """
     Node corresponding to a source directory
     """
-    def add_asset(self, *, src: file.File, name: str) -> Optional[Asset]:
+
+    def add_asset(self, *, src: file.File, name: str) -> Asset | None:
         """
         Add an Asset as a subnode of this one
         """
         # Import here to avoid cyclical imports
         from .asset import Asset
-        return self.create_source_page_as_file(page_cls=Asset, src=src, name=name, dst=name)
+
+        return self.create_source_page_as_file(
+            page_cls=Asset, src=src, name=name, dst=name
+        )
 
     def create_source_page_as_file(
-            self, *,
-            page_cls: Type[P],
-            src: file.File,
-            dst: str,
-            date: Optional[datetime.datetime] = None,
-            **kw: Any) -> Optional[P]:
+        self,
+        *,
+        page_cls: type[P],
+        src: file.File,
+        dst: str,
+        date: datetime.datetime | None = None,
+        **kw: Any,
+    ) -> P | None:
         """
         Create a page of the given type, attaching it at the given path
         """
@@ -44,12 +50,16 @@ class SourceNode(Node):
             raise RuntimeError("source page created with 'created_from' set")
 
         if self.site.last_load_step > self.site.LOAD_STEP_CONTENTS:
-            raise RuntimeError("Node.create_source_page created after the 'contents' step has completed")
+            raise RuntimeError(
+                "Node.create_source_page created after the 'contents' step has completed"
+            )
 
         if self.site.previous_source_footprints:
             # TODO: since we pop, we lose fooprint info for assets that replace other assets.
             # TODO: propagate it when doing the replacement?
-            kw["old_footprint"] = self.site.previous_source_footprints.pop(src.relpath, None)
+            kw["old_footprint"] = self.site.previous_source_footprints.pop(
+                src.relpath, None
+            )
 
         if date is None:
             date = self.site.localized_timestamp(src.stat.st_mtime)
@@ -62,7 +72,9 @@ class SourceNode(Node):
             return None
 
         try:
-            return self._create_leaf_page(page_cls=page_cls, dst=dst, src=src, date=date, **kw)
+            return self._create_leaf_page(
+                page_cls=page_cls, dst=dst, src=src, date=date, **kw
+            )
         except SkipPage:
             return None
 
@@ -73,15 +85,17 @@ class SourceNode(Node):
         if (node := self.sub.get(name)) is not None:
             if not isinstance(node, SourceAssetNode):
                 raise RuntimeError(
-                        f"source node {name} already exists in {self.name}"
-                        f" as {node.__class__.__name__} instead of SourceAssetNode {src.abspath}")
+                    f"source node {name} already exists in {self.name}"
+                    f" as {node.__class__.__name__} instead of SourceAssetNode {src.abspath}"
+                )
             if src not in node.srcs:
                 log.debug("assets: merging %s into %s", src.abspath, node)
                 node.srcs.append(src)
             return node
         else:
-            node = self.site.features.get_node_class(
-                    SourceAssetNode)(site=self.site, name=name, parent=self, src=src)
+            node = self.site.features.get_node_class(SourceAssetNode)(
+                site=self.site, name=name, parent=self, src=src
+            )
             self.sub[name] = node
             return node
 
@@ -90,6 +104,7 @@ class SourceAssetNode(SourceNode):
     """
     Node corresponding to a source directory that contains only asset pages
     """
+
     def __init__(self, site: Site, name: str, *, src: file.File, parent: Node):
         super().__init__(site, name, parent=parent)
         self.srcs: list[file.File] = [src]
@@ -99,17 +114,19 @@ class SourcePageNode(SourceNode):
     """
     Node corresponding to a source directory that contains non-asset pages
     """
-    def __init__(self, site: Site, name: str, *, src: file.File, parent: Optional[Node]):
+
+    def __init__(self, site: Site, name: str, *, src: file.File, parent: Node | None):
         super().__init__(site, name, parent=parent)
         self.src: file.File = src
 
     def create_source_page_as_path(
-            self,
-            page_cls: Type[P],
-            src: file.File,
-            name: str,
-            date: Optional[datetime.datetime] = None,
-            **kw: Any) -> Optional[P]:
+        self,
+        page_cls: type[P],
+        src: file.File,
+        name: str,
+        date: datetime.datetime | None = None,
+        **kw: Any,
+    ) -> P | None:
         """
         Create a page of the given type, attaching it at the given path
         """
@@ -117,12 +134,16 @@ class SourcePageNode(SourceNode):
             raise RuntimeError("source page created with 'created_from' set")
 
         if self.site.last_load_step > self.site.LOAD_STEP_CONTENTS:
-            raise RuntimeError("Node.create_source_page created after the 'contents' step has completed")
+            raise RuntimeError(
+                "Node.create_source_page created after the 'contents' step has completed"
+            )
 
         if self.site.previous_source_footprints:
             # TODO: since we pop, we lose fooprint info for assets that replace other assets.
             # TODO: propagate it when doing the replacement?
-            kw["old_footprint"] = self.site.previous_source_footprints.pop(src.relpath, None)
+            kw["old_footprint"] = self.site.previous_source_footprints.pop(
+                src.relpath, None
+            )
 
         if date is None:
             date = self.site.localized_timestamp(src.stat.st_mtime)
@@ -137,16 +158,19 @@ class SourcePageNode(SourceNode):
         node = self._child(name)
 
         try:
-            return node._create_index_page(page_cls=page_cls, directory_index=False, src=src, date=date, **kw)
+            return node._create_index_page(
+                page_cls=page_cls, directory_index=False, src=src, date=date, **kw
+            )
         except SkipPage:
             return None
 
     def create_source_page_as_index(
-            self,
-            page_cls: Type[P],
-            src: file.File,
-            date: Optional[datetime.datetime] = None,
-            **kw: Any) -> Optional[P]:
+        self,
+        page_cls: type[P],
+        src: file.File,
+        date: datetime.datetime | None = None,
+        **kw: Any,
+    ) -> P | None:
         """
         Create a page of the given type, attaching it at the given path
         """
@@ -154,12 +178,16 @@ class SourcePageNode(SourceNode):
             raise RuntimeError("source page created with 'created_from' set")
 
         if self.site.last_load_step > self.site.LOAD_STEP_CONTENTS:
-            raise RuntimeError("Node.create_source_page created after the 'contents' step has completed")
+            raise RuntimeError(
+                "Node.create_source_page created after the 'contents' step has completed"
+            )
 
         if self.site.previous_source_footprints:
             # TODO: since we pop, we lose fooprint info for assets that replace other assets.
             # TODO: propagate it when doing the replacement?
-            kw["old_footprint"] = self.site.previous_source_footprints.pop(src.relpath, None)
+            kw["old_footprint"] = self.site.previous_source_footprints.pop(
+                src.relpath, None
+            )
 
         if date is None:
             date = self.site.localized_timestamp(src.stat.st_mtime)
@@ -172,7 +200,9 @@ class SourcePageNode(SourceNode):
             return None
 
         try:
-            return self._create_index_page(page_cls=page_cls, directory_index=True, src=src, date=date, **kw)
+            return self._create_index_page(
+                page_cls=page_cls, directory_index=True, src=src, date=date, **kw
+            )
         except SkipPage:
             return None
 
@@ -183,15 +213,19 @@ class SourcePageNode(SourceNode):
         if (node := self.sub.get(name)) is not None:
             if not isinstance(node, SourcePageNode):
                 raise RuntimeError(
-                        f"source node {name} already exists in {self.name}"
-                        f" as {node.__class__.__name__} instead of source node {src.abspath}")
+                    f"source node {name} already exists in {self.name}"
+                    f" as {node.__class__.__name__} instead of source node {src.abspath}"
+                )
             if node.src != src:
                 raise RuntimeError(
-                        f"source node {name} already exists in {self.name}"
-                        f" as {node.src.abspath} instead of {src.abspath}")
+                    f"source node {name} already exists in {self.name}"
+                    f" as {node.src.abspath} instead of {src.abspath}"
+                )
             return node
 
-        node = self.site.features.get_node_class(SourcePageNode)(site=self.site, name=name, parent=self, src=src)
+        node = self.site.features.get_node_class(SourcePageNode)(
+            site=self.site, name=name, parent=self, src=src
+        )
         self.sub[name] = node
         return node
 
@@ -200,13 +234,16 @@ class RootNode(SourcePageNode):
     """
     Node at the root of the site tree
     """
-    title = fields.Str["Node"](doc="""
+
+    title = fields.Str["Node"](
+        doc="""
         Title used as site name.
 
         This only makes sense for the root node of the site hierarchy, and
         takes the value from the title of the root index page. If set, and the
         site name is not set by other means, it is used to give the site a name.
-    """)
+    """
+    )
 
     def __init__(self, site: Site, *, src: file.File):
         super().__init__(site, name="", src=src, parent=None)
