@@ -5,8 +5,8 @@ import logging
 import os
 import re
 from collections import defaultdict
-from typing import (TYPE_CHECKING, Any, Callable, List, MutableMapping,
-                    Optional, Sequence, Type, Union)
+from collections.abc import Callable, MutableMapping, Sequence
+from typing import TYPE_CHECKING, Any
 
 import jinja2
 import jinja2.sandbox
@@ -33,6 +33,7 @@ class Loader:
     """
     Theme loader, resolving theme dependency chains
     """
+
     def __init__(self, search_paths: Sequence[str]):
         # Sequence of search paths to use to resolve theme names
         self.search_paths = search_paths
@@ -52,7 +53,7 @@ class Loader:
         sorted_names = toposort.sort(self.deps)
         return [self.configs[name] for name in sorted_names]
 
-    def load_legacy(self, path: str) -> List[dict[str, Any]]:
+    def load_legacy(self, path: str) -> list[dict[str, Any]]:
         """
         Same as load, but start with a path to an initial theme
         """
@@ -74,7 +75,9 @@ class Loader:
         preceded by all its dependencies
         """
         if name in self.configs:
-            log.warning("%s: dependency loop found between themes: ignoring dependency", name)
+            log.warning(
+                "%s: dependency loop found between themes: ignoring dependency", name
+            )
             return
 
         config = self.load_config(self.find_root(name), name)
@@ -104,7 +107,7 @@ class Loader:
         if not os.path.isfile(pathname):
             config: dict[str, Any] = {}
         else:
-            with open(pathname, "rt") as fd:
+            with open(pathname) as fd:
                 fmt, config = front_matter.read_whole(fd)
 
         # Normalize 'extends' to a list of strings
@@ -138,9 +141,8 @@ class Jinja2TemplateLoader(jinja2.loaders.BaseLoader):
             return self.loader_theme, template
 
     def get_source(
-            self,
-            environment: jinja2.Environment,
-            template: str) -> tuple[str, Optional[str], Optional[Callable[[], bool]]]:
+        self, environment: jinja2.Environment, template: str
+    ) -> tuple[str, str | None, Callable[[], bool] | None]:
         loader, name = self.get_loader(template)
         try:
             return loader.get_source(environment, name)
@@ -151,10 +153,11 @@ class Jinja2TemplateLoader(jinja2.loaders.BaseLoader):
 
     @jinja2.utils.internalcode
     def load(
-            self,
-            environment: jinja2.Environment,
-            name: str,
-            globals: Optional[MutableMapping[str, Any]] = None) -> jinja2.Template:
+        self,
+        environment: jinja2.Environment,
+        name: str,
+        globals: MutableMapping[str, Any] | None = None,
+    ) -> jinja2.Template:
         loader, local_name = self.get_loader(name)
         try:
             return loader.load(environment, local_name, globals)
@@ -188,7 +191,7 @@ class Theme:
         self.jinja2: jinja2.Environment
 
         # Compute template lookup paths
-        self.template_lookup_paths: List[str] = []
+        self.template_lookup_paths: list[str] = []
         for config in reversed(self.configs):
             self.template_lookup_paths.append(config["root"])
         log.info("%s: template lookup paths: %r", self.name, self.template_lookup_paths)
@@ -223,7 +226,9 @@ class Theme:
                 self.meta[key] = config[key]
 
     @classmethod
-    def create(cls, site: Site, name: str, search_paths: Optional[Sequence[str]] = None) -> "Theme":
+    def create(
+        cls, site: Site, name: str, search_paths: Sequence[str] | None = None
+    ) -> Theme:
         """
         Create a Theme looking up its name in the theme search paths
         """
@@ -232,13 +237,14 @@ class Theme:
 
         if search_paths is None:
             search_paths = [
-                os.path.join(site.settings.PROJECT_ROOT, path) for path in site.settings.THEME_PATHS
+                os.path.join(site.settings.PROJECT_ROOT, path)
+                for path in site.settings.THEME_PATHS
             ]
         loader = Loader(search_paths)
         return cls(site, name, loader.load(name))
 
     @classmethod
-    def create_legacy(cls, site: Site, paths: Sequence[str]) -> "Theme":
+    def create_legacy(cls, site: Site, paths: Sequence[str]) -> Theme:
         """
         Create a theme from a list of possible theme paths
         """
@@ -260,7 +266,7 @@ class Theme:
         self.site.features.commit()
         self.site.stage_features_constructed = True
 
-        env_cls: Type[jinja2.Environment]
+        env_cls: type[jinja2.Environment]
         # Jinja2 template engine
         if self.site.settings.JINJA2_SANDBOXED:
             env_cls = jinja2.sandbox.ImmutableSandboxedEnvironment
@@ -290,8 +296,8 @@ class Theme:
             img_for=self.jinja2_img_for,
             now=self.site.generation_time,
             next_month=(
-                self.site.generation_time.replace(day=1) + datetime.timedelta(days=40)).replace(
-                    day=1, hour=0, minute=0, second=0, microsecond=0),
+                self.site.generation_time.replace(day=1) + datetime.timedelta(days=40)
+            ).replace(day=1, hour=0, minute=0, second=0, microsecond=0),
         )
 
         self.jinja2.filters["datetime_format"] = self.jinja2_datetime_format
@@ -332,47 +338,62 @@ class Theme:
 
     @jinja2.pass_context
     def jinja2_datetime_format(
-            self,
-            context: jinja2.runtime.Context,
-            dt: Union[str, datetime.datetime],
-            format: Optional[str] = None) -> str:
+        self,
+        context: jinja2.runtime.Context,
+        dt: str | datetime.datetime,
+        format: str | None = None,
+    ) -> str:
         if not isinstance(dt, datetime.datetime):
             import dateutil.parser
+
             dt = dateutil.parser.parse(dt)
         if format is None or format == "iso8601":
             from .utils import format_date_iso8601
+
             return format_date_iso8601(dt)
         elif format in ("rss2", "rfc822"):
             from .utils import format_date_rfc822
+
             return format_date_rfc822(dt)
         elif format in ("atom", "rfc3339"):
             from .utils import format_date_rfc3339
+
             return format_date_rfc3339(dt)
         elif format == "w3cdtf":
             from .utils import format_date_w3cdtf
+
             return format_date_w3cdtf(dt)
-        elif format[0] == '%':
+        elif format[0] == "%":
             return dt.strftime(format)
         else:
-            log.warning("%s+%s: invalid datetime format %r requested",
-                        context.parent["page"].src.relpath, context.name, format)
-            return "(unknown datetime format {})".format(format)
+            log.warning(
+                "%s+%s: invalid datetime format %r requested",
+                context.parent["page"].src.relpath,
+                context.name,
+                format,
+            )
+            return f"(unknown datetime format {format})"
 
     @jinja2.pass_context
-    def jinja2_next_month(self, context: jinja2.runtime.Context, dt: Any) -> Union[datetime.date, datetime.datetime]:
+    def jinja2_next_month(
+        self, context: jinja2.runtime.Context, dt: Any
+    ) -> datetime.date | datetime.datetime:
         if isinstance(dt, str):
             import dateutil.parser
+
             dt = dateutil.parser.parse(dt)
 
         if isinstance(dt, datetime.datetime):
             return (dt.replace(day=1) + datetime.timedelta(days=40)).replace(
-                    day=1, hour=0, minute=0, second=0, microsecond=0)
+                day=1, hour=0, minute=0, second=0, microsecond=0
+            )
         elif isinstance(dt, datetime.date):
             return (dt.replace(day=1) + datetime.timedelta(days=40)).replace(day=1)
         else:
             raise RuntimeError(
-                    f"{context.parent['page']}+{context.name}: invalid datetime {dt!r} of type {type(dt)}:"
-                    " accepted are str, datetime, date")
+                f"{context.parent['page']}+{context.name}: invalid datetime {dt!r} of type {type(dt)}:"
+                " accepted are str, datetime, date"
+            )
 
     @jinja2.pass_context
     def jinja2_has_page(self, context: jinja2.runtime.Context, arg: str) -> bool:
@@ -385,16 +406,18 @@ class Theme:
             return True
 
     @jinja2.pass_context
-    def jinja2_page_for(self, context: jinja2.runtime.Context, arg: Union[str, Page]) -> Page:
+    def jinja2_page_for(self, context: jinja2.runtime.Context, arg: str | Page) -> Page:
         """
         Generate a URL for a page, specified by path or with the page itself
         """
         if isinstance(arg, Page):
             return arg
 
-        cur_page: Optional[Page] = context.get("page")
+        cur_page: Page | None = context.get("page")
         if cur_page is None:
-            raise RuntimeError(f"{cur_page}+{context.name}: page_for({arg!r}): current page is not defined")
+            raise RuntimeError(
+                f"{cur_page}+{context.name}: page_for({arg!r}): current page is not defined"
+            )
 
         try:
             return cur_page.resolve_path(arg)
@@ -403,18 +426,24 @@ class Theme:
 
     @jinja2.pass_context
     def jinja2_url_for(
-            self,
-            context: jinja2.runtime.Context,
-            arg: Union[str, Page],
-            absolute: bool = False,
-            static: bool = False) -> str:
+        self,
+        context: jinja2.runtime.Context,
+        arg: str | Page,
+        absolute: bool = False,
+        static: bool = False,
+    ) -> str:
         """
         Generate a URL for a page, specified by path or with the page itself
         """
-        cur_page: Optional[Page] = context.get("page")
+        cur_page: Page | None = context.get("page")
         # print(f"Theme.jinja2_url_for {cur_page=!r}")
         if cur_page is None:
-            log.warning("%s+%s: url_for(%s): current page is not defined", cur_page, context.name, arg)
+            log.warning(
+                "%s+%s: url_for(%s): current page is not defined",
+                cur_page,
+                context.name,
+                arg,
+            )
             return ""
 
         try:
@@ -424,31 +453,46 @@ class Theme:
             return ""
 
     @jinja2.pass_context
-    def jinja2_site_pages(self, context: jinja2.runtime.Context, **kw: Any) -> list[Page]:
-        cur_page: Optional[Page] = context.get("page")
+    def jinja2_site_pages(
+        self, context: jinja2.runtime.Context, **kw: Any
+    ) -> list[Page]:
+        cur_page: Page | None = context.get("page")
         if cur_page is None:
-            log.warning("%s+%s: site_pages: current page is not defined", cur_page, context.name)
+            log.warning(
+                "%s+%s: site_pages: current page is not defined", cur_page, context.name
+            )
             return []
 
         return cur_page.find_pages(**kw)
 
     @jinja2.pass_context
     def jinja2_img_for(
-            self, context: jinja2.runtime.Context,
-            path: Union[str, Page],
-            type: Optional[str] = None,
-            absolute: bool = False,
-            **attrs: Any) -> str:
+        self,
+        context: jinja2.runtime.Context,
+        path: str | Page,
+        type: str | None = None,
+        absolute: bool = False,
+        **attrs: Any,
+    ) -> str:
         cur_page = context.get("page")
         if cur_page is None:
-            log.warning("%s+%s: img(%s): current page is not defined", cur_page, context.name, path)
+            log.warning(
+                "%s+%s: img(%s): current page is not defined",
+                cur_page,
+                context.name,
+                path,
+            )
             return ""
 
         image_page = cur_page.resolve_path(path)
         if isinstance(image_page, ImagePage):
             res_attrs = image_page.get_img_attributes(type=type, absolute=absolute)
         else:
-            log.warning("%s: img src= resolves to %s which is not an image page", cur_page, image_page)
+            log.warning(
+                "%s: img src= resolves to %s which is not an image page",
+                cur_page,
+                image_page,
+            )
             res_attrs = {"src": cur_page.url_for(image_page)}
 
         escape = markupsafe.escape
@@ -459,10 +503,10 @@ class Theme:
         return markupsafe.Markup("".join(res))
 
     def jinja2_arrange(
-            self,
-            pages: Union[Pages, list[Page]],
-            *args: Any, **kw: Any) -> list[Page]:
+        self, pages: Pages | list[Page], *args: Any, **kw: Any
+    ) -> list[Page]:
         from .page import Pages
+
         if isinstance(pages, Pages):
             return pages.arrange(*args, **kw)
         else:
