@@ -5,7 +5,8 @@ import datetime
 import logging
 import os
 import time
-from typing import Any, Generator, Optional, Union
+from collections.abc import Generator
+from typing import Any
 
 import pytz
 
@@ -14,6 +15,7 @@ log = logging.getLogger("utils")
 
 def format_date_rfc822(dt: datetime.datetime) -> str:
     from email.utils import formatdate
+
     return formatdate(dt.timestamp())
 
 
@@ -25,24 +27,24 @@ def format_date_rfc3339(dt: datetime.datetime) -> str:
 def format_date_w3cdtf(dt: datetime.datetime) -> str:
     offset = dt.utcoffset()
     if offset:
-        offset_sec = (offset.days * 24 * 3600 + offset.seconds)
+        offset_sec = offset.days * 24 * 3600 + offset.seconds
         offset_hrs = offset_sec // 3600
         offset_min = offset_sec % 3600
-        tz_str = '{0:+03d}:{1:02d}'.format(offset_hrs, offset_min // 60)
+        tz_str = f"{offset_hrs:+03d}:{offset_min // 60:02d}"
     else:
-        tz_str = 'Z'
+        tz_str = "Z"
     return dt.strftime("%Y-%m-%dT%H:%M:%S") + tz_str
 
 
 def format_date_iso8601(dt: datetime.datetime) -> str:
     offset = dt.utcoffset()
     if offset:
-        offset_sec = (offset.days * 24 * 3600 + offset.seconds)
+        offset_sec = offset.days * 24 * 3600 + offset.seconds
         offset_hrs = offset_sec // 3600
         offset_min = offset_sec % 3600
-        tz_str = '{0:+03d}:{1:02d}'.format(offset_hrs, offset_min // 60)
+        tz_str = f"{offset_hrs:+03d}:{offset_min // 60:02d}"
     else:
-        tz_str = 'Z'
+        tz_str = "Z"
     return dt.strftime("%Y-%m-%d %H:%M:%S") + tz_str
 
 
@@ -60,13 +62,26 @@ def timings(fmtstr: str, *args: Any, **kw: Any) -> Generator[None, None, None]:
     log.info(fmtstr, (end - start) / 1_000_000_000, *args, extra=kw)
 
 
-def dump_meta(val: Any) -> Union[None, bool, int, float, str, list[Any], tuple[Any, ...], set[Any], dict[str, Any]]:
+def dump_meta(
+    val: Any,
+) -> (
+    None
+    | bool
+    | int
+    | float
+    | str
+    | list[Any]
+    | tuple[Any, ...]
+    | set[Any]
+    | dict[str, Any]
+):
     """
     Dump data into a dict, for use with dump_meta in to_dict methods
     """
     import jinja2
 
     from ..page import Page
+
     if val is None:
         return None
     elif isinstance(val, (bool, int, float)):
@@ -88,7 +103,7 @@ def dump_meta(val: Any) -> Union[None, bool, int, float, str, list[Any], tuple[A
 
 
 @contextlib.contextmanager
-def open_dir_fd(path: str, dir_fd: Optional[int] = None) -> Generator[int, None, None]:
+def open_dir_fd(path: str, dir_fd: int | None = None) -> Generator[int, None, None]:
     """
     Return a dir_fd for a directory. Supports dir_fd for opening.
     """
