@@ -1,7 +1,9 @@
 from __future__ import annotations
-from unittest import TestCase
-from . import utils as test_utils
+
 import datetime
+from unittest import TestCase
+
+from . import utils as test_utils
 
 
 def dt(*args):
@@ -12,15 +14,31 @@ class TestSeries(test_utils.MockSiteTestMixin, TestCase):
     def test_site(self):
         files = {
             "series.taxonomy": "",
-            "seriesa1.md": {"series": "seriesa", "title": "Series A", "date": dt(2016, 1, 1)},
+            "seriesa1.md": {
+                "series": "seriesa",
+                "title": "Series A",
+                "date": dt(2016, 1, 1),
+            },
             "seriesa2.md": {"date": dt(2016, 1, 2), "series": "seriesa", "title": "A2"},
-            "seriesa3.md": {"date": dt(2016, 1, 3), "series": "seriesa", "title": "A3",
-                            "series_title": "Series A part Two"},
+            "seriesa3.md": {
+                "date": dt(2016, 1, 3),
+                "series": "seriesa",
+                "title": "A3",
+                "series_title": "Series A part Two",
+            },
             "seriesa4.md": {"date": dt(2016, 1, 4), "series": "seriesa", "title": "A4"},
-            "seriesb1.md": {"date": dt(2016, 1, 1), "series": "seriesb",
-                            "title": "Series B Intro", "series_title": "Series B"},
+            "seriesb1.md": {
+                "date": dt(2016, 1, 1),
+                "series": "seriesb",
+                "title": "Series B Intro",
+                "series_title": "Series B",
+            },
             "seriesb2.md": {"date": dt(2016, 1, 2), "series": "seriesb", "title": "B2"},
-            "seriesc1.md": {"date": dt(2016, 1, 1), "title": "Series C", "series": "seriesc"},
+            "seriesc1.md": {
+                "date": dt(2016, 1, 1),
+                "title": "Series C",
+                "series": "seriesc",
+            },
             "noseries.md": {"date": dt(2016, 1, 1), "title": "Other things"},
         }
 
@@ -42,18 +60,24 @@ class TestSeries(test_utils.MockSiteTestMixin, TestCase):
             self.assertEqual(len(series.categories), 3)
 
             # Check the contents of series (check in tags)
-            self.assertEqual(series.categories["seriesa"].pages, [seriesa1, seriesa2, seriesa3, seriesa4])
+            self.assertEqual(
+                series.categories["seriesa"].pages,
+                [seriesa1, seriesa2, seriesa3, seriesa4],
+            )
             self.assertEqual(series.categories["seriesb"].pages, [seriesb1, seriesb2])
             self.assertEqual(series.categories["seriesc"].pages, [seriesc1])
 
             # Check computed series metadata
-            self.assertEqual(series.categories["seriesa"].series_info, {
-                "pages": [seriesa1, seriesa2, seriesa3, seriesa4],
-                "length": 4,
-                "first": seriesa1,
-                "last": seriesa4,
-                "title": "Series A",
-            })
+            self.assertEqual(
+                series.categories["seriesa"].series_info,
+                {
+                    "pages": [seriesa1, seriesa2, seriesa3, seriesa4],
+                    "length": 4,
+                    "first": seriesa1,
+                    "last": seriesa4,
+                    "title": "Series A",
+                },
+            )
 
             s = series.categories["seriesa"].sequence(seriesa1)
             self.assertEqual(s["title"], "Series A")
@@ -91,13 +115,16 @@ class TestSeries(test_utils.MockSiteTestMixin, TestCase):
             self.assertEqual(s["index"], 4)
             self.assertEqual(s["length"], 4)
 
-            self.assertEqual(series.categories["seriesb"].series_info, {
-                "pages": [seriesb1, seriesb2],
-                "length": 2,
-                "first": seriesb1,
-                "last": seriesb2,
-                "title": "Series B",
-            })
+            self.assertEqual(
+                series.categories["seriesb"].series_info,
+                {
+                    "pages": [seriesb1, seriesb2],
+                    "length": 2,
+                    "first": seriesb1,
+                    "last": seriesb2,
+                    "title": "Series B",
+                },
+            )
 
             s = series.categories["seriesb"].sequence(seriesb1)
             self.assertEqual(s["title"], "Series B")
