@@ -1,7 +1,8 @@
 from unittest import TestCase
-from staticsite.utils import front_matter
+
 import toml
 
+from staticsite.utils import front_matter
 
 toml_valid = """+++
 date = "Tue, 24 Aug 2010 13:13:38 +0000"
@@ -23,11 +24,14 @@ class TestToml(TestCase):
         self.maxDiff = None
         fmt, data = front_matter.read_string(toml_valid)
         self.assertEqual(fmt, "toml")
-        self.assertEqual(data, {
-            "date": "Tue, 24 Aug 2010 13:13:38 +0000",
-            "tags": ["valid"],
-            "bool": True,
-        })
+        self.assertEqual(
+            data,
+            {
+                "date": "Tue, 24 Aug 2010 13:13:38 +0000",
+                "tags": ["valid"],
+                "bool": True,
+            },
+        )
 
     def test_invalid_bool(self):
         with self.assertRaises(toml.decoder.TomlDecodeError):
